import * as React from "react";
import AppBar from "@mui/material/AppBar";
import Box from "@mui/material/Box";
import Divider from "@mui/material/Divider";
import Drawer from "@mui/material/Drawer";
import IconButton from "@mui/material/IconButton";
import InboxIcon from "@mui/icons-material/MoveToInbox";
import List from "@mui/material/List";
import ListItem from "@mui/material/ListItem";
import ListItemIcon from "@mui/material/ListItemIcon";
import ListItemText from "@mui/material/ListItemText";
import MailIcon from "@mui/icons-material/Mail";
import MenuIcon from "@mui/icons-material/Menu";
import Toolbar from "@mui/material/Toolbar";
import Typography from "@mui/material/Typography";
import LogoutIcon from "@mui/icons-material/Logout";
import Container from "@mui/material/Container";
import SettingsGeneral from "./settingsGeneral";
import { Link, Route, Switch, useRouteMatch } from "react-router-dom";
import SettingsGameruns from "./settingsGameruns";
import SettingsEmailInfo from "./settingsEmailInfo";
import SettingsGamerunInfo from "./settingsGamerunInfo";
import SettingsEmails from "./settingsEmails";
import EmailForm from "../../components/EmailForm";
import PropTypes from "prop-types";
import { connect } from "react-redux";
import { logout } from "../../actions/auth";

const drawerWidth = 240;

// Main Settings page, contains only drawer (navigating to general/emails/gameruns) and Appbar
function SettingsPage(props) {
  const { window } = props;
  const [mobileOpen, setMobileOpen] = React.useState(false);
  let match = useRouteMatch();

  // handler for opening navbar on mobiles
  const handleDrawerToggle = () => {
    setMobileOpen(!mobileOpen);
  };

  const drawer = (
    <div>
      <Toolbar />
      <Divider />
      <List>
        {
          // list navigation items into list
          ["General", "Emails", "Gameruns"].map((text, index) => (
            //  icon with text
            <Box
              key={index}
              component={Link}
              to={`${match.path}/` + text.toLowerCase()} // navigate to /settings/:text
              style={{ textDecoration: "none", color: "#ffffff" }}
            >
              <ListItem button key={text}>
                <ListItemIcon>
                  {index % 2 === 0 ? <InboxIcon /> : <MailIcon />}
                </ListItemIcon>

                <ListItemText primary={text} />
              </ListItem>
            </Box>
          ))
        }
        {/* Logout item */}
        <Link style={{ textDecoration: "none", color: "#ffffff" }} to="/">
          <ListItem
            button
            key={"Logout"}
            onClick={props.logout}
            sx={{ mt: 40 }}
          >
            <ListItemIcon>
              <LogoutIcon />
            </ListItemIcon>
            <ListItemText primary={"Logout"} />
          </ListItem>
        </Link>
      </List>
    </div>
  );

  return (
    // AppBar with name of opened page
    <Box sx={{ display: "flex" }}>
      <AppBar
        position="fixed"
        sx={{
          width: { sm: `calc(100% - ${drawerWidth}px)` },
          ml: { sm: `${drawerWidth}px` },
        }}
      >
        <Toolbar>
          <IconButton
            aria-label="open drawer"
            edge="start"
            onClick={handleDrawerToggle}
            sx={{ mr: 2, display: { sm: "none" } }}
          >
            <MenuIcon />
          </IconButton>
          {/* TODO dynamic change of navbar text */}
          <Typography variant="h6" noWrap component="div">
            Responsive drawer
          </Typography>
        </Toolbar>
      </AppBar>
      {/* Navigation Menu */}
      <Box
        component="nav"
        sx={{ width: { sm: drawerWidth }, flexShrink: { sm: 0 } }}
      >
        <Drawer
          variant="temporary"
          open={mobileOpen}
          onClose={handleDrawerToggle}
          ModalProps={{
            keepMounted: true,
          }}
          sx={{
            display: { xs: "block", sm: "none" },
            "& .MuiDrawer-paper": {
              boxSizing: "border-box",
              width: drawerWidth,
            },
          }}
        >
          {drawer}
        </Drawer>
        <Drawer
          variant="permanent"
          sx={{
            display: { xs: "none", sm: "block" },
            "& .MuiDrawer-paper": {
              boxSizing: "border-box",
              width: drawerWidth,
            },
          }}
        >
          {drawer}
        </Drawer>
      </Box>
      {/* Container with routing to different pages */}
      <Container>
        <Toolbar />
        <Switch>
          {/* route to general settings */}
          <Route path={`${match.path}/general`} component={SettingsGeneral} />
          {/* route to email page with EmailTable */}
          <Route
            path={`${match.path}/emails`}
            exact
            component={SettingsEmails}
          />
          {/* route to gamerun page with GamerunTable */}
          <Route
            path={`${match.path}/gameruns`}
            exact
            component={SettingsGameruns}
          />
          {/* route to page containing info about email */}
          <Route path={`*/emails/:id`} component={SettingsEmailInfo} />
          {/* route to page containing info about gamerun */}
          <Route
            path={`${match.path}/gameruns/:id`}
            component={SettingsGamerunInfo}
          />
          {/* route to page with form for creating new email */}
          <Route path={`${match.path}/new_email`} component={EmailForm} />
        </Switch>
      </Container>
    </Box>
  );
}

SettingsPage.propTypes = {
  auth: PropTypes.object.isRequired,
  logout: PropTypes.func.isRequired,
};

const mapStateToProps = (state) => ({
  auth: state.auth,
});

export default connect(mapStateToProps, { logout })(SettingsPage);
