import Paper from "@mui/material/Paper";
import Box from "@mui/material/Box";
import { Button, Typography } from "@mui/material";
import { useEffect, useState } from "react";
import Grid from "@mui/material/Grid";
import axios from "axios";
import { Link, Redirect } from "react-router-dom";
import CheckIcon from "@mui/icons-material/Check";
import CloseIcon from "@mui/icons-material/Close";
import { useHistory, useLocation } from "react-router";
import { fetchCurrentGamerunSummary } from "../helpers/gameruns";

// Page with summary of current player's gamerun
export default function SummaryPage() {
  // msg, containing username and number of correct answers
  const [msg, setMsg] = useState();
  const location = useLocation();
  const username = localStorage.getItem("username");
  // emails of current gamerun also containing statistics
  const [emailsWStats, setEmailsWStats] = useState([]);
  const history = useHistory();

  const countCorrectAnswers = (emails) => {
    return emails.filter((email) => email.answer.correctness === true).length;
  };

  useEffect(() => {
    if (!username) {
      //redirect to usernaem PAge
    }
    fetchCurrentGamerunSummary()
      .then((data) => {
        setEmailsWStats(data);
        setMsg(
          username +
            ", You have " +
            countCorrectAnswers(data) +
            "/" +
            data.length +
            " correct"
        );
      })
      .catch((err) => history.push("/username"));
  }, [location]);

  // Play again button, located on top and bottom of page, redirects to username page
  const PlayAgainButton = (
    <Box
      sx={{
        display: "flex",
        width: "100%",
        justifyContent: "center",
        my: 4,
      }}
    >
      <Button
        sx={{ marginX: "auto" }}
        variant="contained"
        component={Link}
        to="/username"
      >
        play again
      </Button>
    </Box>
  );

  // Paper contains email subject, sender, body
  function EmailWindow(props) {
    return (
      <Paper sx={{ width: "60%", height: 300 }}>
        <Box
          sx={{
            display: "flex",
            flexDirection: "column",
            width: "95%",
            height: "20%",
            margin: "auto",
            justifyContent: "center",
          }}
        >
          <Typography variant="h5">{props.currentEmail.subject}</Typography>
          <Typography variant="body2">{props.currentEmail.sender}</Typography>
        </Box>
        <Box
          sx={{
            width: "95%",
            height: "70%",
            margin: "auto",
          }}
        >
          <Paper
            sx={{ width: "100%", height: "100%", overflowY: "auto", border: 1 }}
          >
            <Typography
              sx={{ wordWrap: "break-word", padding: 2 }}
              variant="body2"
            >
              {props.currentEmail.body}
            </Typography>
          </Paper>
        </Box>
      </Paper>
    );
  }

  return (
    <div>
      {/* Paper with message (username and number of correct answers)*/}
      <Paper
        sx={{
          width: "95%",
          height: "10vh",
          display: "flex",
          alignItems: "center",
          justifyContent: "center",
          margin: "auto",
          mt: 1,
        }}
      >
        {msg}
      </Paper>
      {PlayAgainButton}
      <Grid container spacing={6}>
        {
          // map emails into email window and statistics
          emailsWStats.map((email, index) => (
            <Grid item container key={index}>
              {/* Email window */}
              <Grid item xs={12} sm={6}>
                <Box
                  sx={{
                    display: "flex",
                    width: "100%",
                    justifyContent: "center",
                  }}
                >
                  <EmailWindow currentEmail={email.email} />
                </Box>
              </Grid>
              {/* Paper with statistics */}
              <Grid item xs={12} sm={6}>
                <Paper
                  sx={{
                    margin: "0 auto",
                    width: "40%",
                    height: 300,
                    padding: 2,
                    display: "flex",
                    flexDirection: "column",
                  }}
                >
                  <Typography>
                    Average correctness: {email.average_correctness}%
                  </Typography>
                  <Typography>Your time: {email.players_duration}</Typography>

                  <Typography>
                    Average duration: {email.average_duration}
                  </Typography>
                  <Box
                    sx={{
                      display: "flex",
                      flex: 1,
                      flexDirection: "column",
                      justifyContent: "flex-end",
                    }}
                  >
                    <Typography variant="h6">
                      Your answer:
                      {
                        // if answer is true = "Phishing", otherwise "Legitimate"
                        email.answer.player_answer === true
                          ? "Phishing"
                          : "Legitimate"
                      }
                      {
                        // if answer was correct, show check icon, otherwise X
                        email.answer.correctness === true ? (
                          <CheckIcon sx={{ color: "green" }} />
                        ) : (
                          <CloseIcon sx={{ color: "red" }} />
                        )
                      }
                    </Typography>
                  </Box>
                </Paper>
              </Grid>
            </Grid>
          ))
        }
      </Grid>
      {PlayAgainButton}
    </div>
  );
}
